@@ -55,7 +55,7 @@ class AwsClient:
             bucket = get_config_attr(config, 'aws_s3_bucket')
             if '.' in bucket:
                 # assumes the bucket is a domain and is already as a CNAME record for S3
-                self.host = get_config_attr(config, 'aws_s3_bucket')
+                self.host = bucket
             else:
                 self.host = f'{bucket}.s3.amazonaws.com'
 
@@ -64,6 +64,21 @@ class AwsClient:
     async def get(self, path: str = '', *, params: Optional[Dict[str, Any]] = None) -> Response:
         return await self.request('GET', path=path, params=params)
 
+    async def raw_post(
+        self,
+        url: str,
+        *,
+        expected_status: int,
+        params: Optional[Dict[str, Any]] = None,
+        data: Optional[Dict[str, str]] = None,
+        files: Optional[Dict[str, bytes]] = None,
+    ) -> Response:
+        r = await self.client.post(url, params=params, data=data, files=files)
+        if r.status_code == expected_status:
+            return r
+        else:
+            raise RequestError(r)
+
     async def post(
         self,
         path: str = '',
